==> realwear_voice_command-0.2.0.tar.gz: lib/widgets/voice_command_widget_model.dart <==
import 'dart:async';

import 'package:event_bus/event_bus.dart';
import 'package:realwear_voice_command/core/voice_command_manager.dart';
import 'package:realwear_voice_command/events/voice_command_received_event.dart';
import 'package:realwear_voice_command/models/voice_command.dart';
import 'package:suga_core/suga_core.dart';
import 'package:visibility_detector/visibility_detector.dart';

class VoiceCommandWidgetModel extends BaseViewModel {
  bool _isVisible = true;
  Set<VoiceCommand> _commands = {};
  late Function(VoiceCommand) onCommandReceived;
  StreamSubscription? _voiceCommandReceivedEventListener;

  final EventBus _eventBus;
  final VoiceCommandManager _voiceCommandManager;

  VoiceCommandWidgetModel(
    this._eventBus,
    this._voiceCommandManager,
  );

  Set<VoiceCommand> get commands => _commands;

  set commands(Set<VoiceCommand> value) {
    if (_isVisible) {
      _removeCommands();
    }
    _commands = value;
    if (_isVisible) {
      _addCommands();
    }
  }

  Future<Unit> _addCommands() {
    return run(
      () => _voiceCommandManager.add(_commands),
      showLoading: false,
    );
  }

  Future<Unit> _removeCommands() {
    return run(
      () => _voiceCommandManager.remove(_commands),
      showLoading: false,
    );
  }

  @override
  void initState() {
    _registerEvent();
    super.initState();
  }

  void _registerEvent() {
    _voiceCommandReceivedEventListener = _eventBus.on<VoiceCommandReceivedEvent>().listen((event) {
      if (_isVisible && _commands.any((e) => e == event.command)) {
        onCommandReceived(event.command);
      }
    });
  }

  @override
  void disposeState() {
    _voiceCommandReceivedEventListener?.cancel();
    _removeCommands();
    super.disposeState();
  }

  void onVisibilityChanged(VisibilityInfo info) {
    _isVisible = info.visibleFraction > 0;
    if (_isVisible) {
      _addCommands();
    } else {
      _removeCommands();
    }
  }
}

==> realwear_voice_command-1.1.0.tar.gz: lib/widgets/voice_command_widget_model.dart <==
import 'dart:async';

import 'package:event_bus/event_bus.dart';
import 'package:realwear_voice_command/core/voice_command_manager.dart';
import 'package:realwear_voice_command/events/voice_command_received_event.dart';
import 'package:realwear_voice_command/models/voice_command.dart';
import 'package:suga_core/suga_core.dart';
import 'package:visibility_detector/visibility_detector.dart';

class VoiceCommandWidgetModel extends BaseViewModel {
  bool _isVisible = true;
  Set<VoiceCommand> _commands = {};
  late Function(VoiceCommand) onCommandReceived;
  StreamSubscription? _voiceCommandReceivedEventListener;

  final EventBus _eventBus;
  final VoiceCommandManager _voiceCommandManager;

  VoiceCommandWidgetModel(
    this._eventBus,
    this._voiceCommandManager,
  );

  Set<VoiceCommand> get commands => _commands;

  set commands(Set<VoiceCommand> value) {
    if (_isVisible) {
      _removeCommands();
    }
    _commands = value;
    if (_isVisible) {
      _addCommands();
    }
  }

  Future<Unit> _addCommands() async {
    await run(
      () => _voiceCommandManager.add(_commands),
      shouldHandleError: false,
    );
    return unit;
  }

  Future<Unit> _removeCommands() async {
    await run(
      () => _voiceCommandManager.remove(_commands),
      shouldHandleError: false,
    );
    return unit;
  }

  @override
  void initState() {
    _registerEvent();
    super.initState();
  }

  void _registerEvent() {
    _voiceCommandReceivedEventListener = _eventBus.on<VoiceCommandReceivedEvent>().listen((event) {
      if (_isVisible && _commands.any((e) => e == event.command)) {
        onCommandReceived(event.command);
      }
    });
  }

  @override
  void disposeState() {
    _voiceCommandReceivedEventListener?.cancel();
    _removeCommands();
    super.disposeState();
  }

  @override
  Future<Unit> handleError(error) {
    return Future.value(unit);
  }

  void onVisibilityChanged(VisibilityInfo info) {
    _isVisible = info.visibleFraction > 0;
    if (_isVisible) {
      _addCommands();
    } else {
      _removeCommands();
    }
  }
}
